From mboxrd@z Thu Jan 1 00:00:00 1970 Subject: [PATCH v2 5/7] EmulatorPkg: Fix various typos To: devel@edk2.groups.io From: =?UTF-8?B?Q8WTdXI=?= X-Originating-Location: Tokyo, JP (199.47.199.26) X-Originating-Platform: Mac Chrome 75 User-Agent: GROUPS.IO Web Poster MIME-Version: 1.0 Date: Tue, 02 Jul 2019 09:43:01 -0700 Message-ID: <21474.1562085781059589819@groups.io> Content-Type: multipart/alternative; boundary="fnc493s6E4jEsL7WNY3Z" --fnc493s6E4jEsL7WNY3Z Content-Type: text/plain; charset="utf-8" Content-Transfer-Encoding: quoted-printable Fix various typos in EmulatorPkg. Contributed-under: TianoCore Contribution Agreement 1.1 Signed-off-by: Coeur --- EmulatorPkg/Sec/Ia32/SwitchRam.S=C2=A0 =C2=A0| 18 +++++++++--------- EmulatorPkg/Sec/Ia32/SwitchRam.asm | 20 ++++++++++---------- EmulatorPkg/Sec/Sec.c=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 |=C2= = =A0 5 ++--- EmulatorPkg/Sec/Sec.h=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 |=C2= = =A0 4 ++-- EmulatorPkg/Sec/X64/SwitchRam.S=C2=A0 =C2=A0 |=C2=A0 2 +- EmulatorPkg/Sec/X64/SwitchRam.asm=C2=A0 |=C2=A0 2 +- 6 files changed, 25 insertions(+), 26 deletions(-) diff --git a/EmulatorPkg/Sec/Ia32/SwitchRam.S b/EmulatorPkg/Sec/Ia32/Switc= hRam.S index f24529cc8e..d8298223a9 100644 --- a/EmulatorPkg/Sec/Ia32/SwitchRam.S +++ b/EmulatorPkg/Sec/Ia32/SwitchRam.S @@ -9,7 +9,7 @@ # # Abstract: # -#=C2=A0 =C2=A0Switch the stack from temporary memory to permenent memory. +#=C2=A0 =C2=A0Switch the stack from temporary memory to permanent memory. # #-------------------------------------------------------------------------= ----- @@ -36,7 +36,7 @@ ASM_PFX(SecSwitchStack): # # !!CAUTION!! this function address's is pushed into stack after -# migration of whole temporary memory, so need save it to permenent +# migration of whole temporary memory, so need save it to permanent # memory at first! # @@ -44,14 +44,14 @@ ASM_PFX(SecSwitchStack): movl=C2=A0 24(%esp), %ecx=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 # Save = the second parameter # -# Save this function's return address into permenent memory at first. -# Then, Fixup the esp point to permenent memory +# Save this function's return address into permanent memory at first. +# Then, Fixup the esp point to permanent memory # movl=C2=A0 %esp, %eax subl=C2=A0 %ebx, %eax addl=C2=A0 %ecx, %eax -=C2=A0 =C2=A0 movl=C2=A0 (%esp), %edx=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 = =C2=A0 =C2=A0 =C2=A0 =C2=A0# copy pushed register's value to permenent mem= ory +=C2=A0 =C2=A0 movl=C2=A0 (%esp), %edx=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 = =C2=A0 =C2=A0 =C2=A0 =C2=A0# copy pushed register's value to permanent mem= ory movl=C2=A0 %edx, (%eax) movl=C2=A0 4(%esp), %edx movl=C2=A0 %edx, 4(%eax) @@ -61,16 +61,16 @@ ASM_PFX(SecSwitchStack): movl=C2=A0 %edx, 12(%eax) movl=C2=A0 16(%esp), %edx movl=C2=A0 %edx, 16(%eax) -=C2=A0 =C2=A0 movl=C2=A0 %eax, %esp=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2= = =A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0# From now, esp is pointed to permenent mem= ory +=C2=A0 =C2=A0 movl=C2=A0 %eax, %esp=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2= = =A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0# From now, esp is pointed to permanent mem= ory # -# Fixup the ebp point to permenent memory +# Fixup the ebp point to permanent memory # #ifndef __APPLE__ movl=C2=A0 =C2=A0%ebp, %eax subl=C2=A0 =C2=A0%ebx, %eax addl=C2=A0 =C2=A0%ecx, %eax -=C2=A0 =C2=A0 movl=C2=A0 =C2=A0%eax, %ebp=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2= =A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 # From now, ebp is pointed to permenent me= mory +=C2=A0 =C2=A0 movl=C2=A0 =C2=A0%eax, %ebp=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2= =A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 # From now, ebp is pointed to permanent me= mory # # Fixup callee's ebp point for PeiDispatch @@ -78,7 +78,7 @@ ASM_PFX(SecSwitchStack): movl=C2=A0 =C2=A0(%ebp), %eax subl=C2=A0 =C2=A0%ebx, %eax addl=C2=A0 =C2=A0%ecx, %eax -=C2=A0 =C2=A0 movl=C2=A0 =C2=A0%eax, (%ebp)=C2=A0 =C2=A0 =C2=A0 =C2=A0 = =C2=A0 =C2=A0 =C2=A0 =C2=A0 # From now, Temporary's PPI caller's stack is = in permenent memory +=C2=A0 =C2=A0 movl=C2=A0 =C2=A0%eax, (%ebp)=C2=A0 =C2=A0 =C2=A0 =C2=A0 = =C2=A0 =C2=A0 =C2=A0 =C2=A0 # From now, Temporary's PPI caller's stack is = in permanent memory #endif pop=C2=A0 =C2=A0%edx diff --git a/EmulatorPkg/Sec/Ia32/SwitchRam.asm b/EmulatorPkg/Sec/Ia32/Swi= tchRam.asm index 9c7908f7a0..99ef002980 100644 --- a/EmulatorPkg/Sec/Ia32/SwitchRam.asm +++ b/EmulatorPkg/Sec/Ia32/SwitchRam.asm @@ -9,7 +9,7 @@ ; ; Abstract: ; -;=C2=A0 =C2=A0Switch the stack from temporary memory to permenent memory. +;=C2=A0 =C2=A0Switch the stack from temporary memory to permanent memory. ; ;-------------------------------------------------------------------------= ----- @@ -36,7 +36,7 @@ SecSwitchStack=C2=A0 =C2=A0PROC ; ; !!CAUTION!! this function address's is pushed into stack after -=C2=A0 =C2=A0 ; migration of whole temporary memory, so need save it to p= ermenent +=C2=A0 =C2=A0 ; migration of whole temporary memory, so need save it to p= ermanent ; memory at first! ; @@ -44,13 +44,13 @@ SecSwitchStack=C2=A0 =C2=A0PROC mov=C2=A0 =C2=A0ecx, [esp + 24]=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 ; Save t= he second parameter ; -=C2=A0 =C2=A0 ; Save this function's return address into permenent memory= at first. -=C2=A0 =C2=A0 ; Then, Fixup the esp point to permenent memory +=C2=A0 =C2=A0 ; Save this function's return address into permanent memory= at first. +=C2=A0 =C2=A0 ; Then, Fixup the esp point to permanent memory ; mov=C2=A0 =C2=A0eax, esp sub=C2=A0 =C2=A0eax, ebx add=C2=A0 =C2=A0eax, ecx -=C2=A0 =C2=A0 mov=C2=A0 =C2=A0edx, dword ptr [esp]=C2=A0 =C2=A0 =C2=A0 = =C2=A0 =C2=A0; copy pushed register's value to permenent memory +=C2=A0 =C2=A0 mov=C2=A0 =C2=A0edx, dword ptr [esp]=C2=A0 =C2=A0 =C2=A0 = =C2=A0 =C2=A0; copy pushed register's value to permanent memory mov=C2=A0 =C2=A0dword ptr [eax], edx mov=C2=A0 =C2=A0edx, dword ptr [esp + 4] mov=C2=A0 =C2=A0dword ptr [eax + 4], edx @@ -58,17 +58,17 @@ SecSwitchStack=C2=A0 =C2=A0PROC mov=C2=A0 =C2=A0dword ptr [eax + 8], edx mov=C2=A0 =C2=A0edx, dword ptr [esp + 12] mov=C2=A0 =C2=A0dword ptr [eax + 12], edx -=C2=A0 =C2=A0 mov=C2=A0 =C2=A0edx, dword ptr [esp + 16]=C2=A0 =C2=A0 ; Up= date this function's return address into permenent memory +=C2=A0 =C2=A0 mov=C2=A0 =C2=A0edx, dword ptr [esp + 16]=C2=A0 =C2=A0 ; Up= date this function's return address into permanent memory mov=C2=A0 =C2=A0dword ptr [eax + 16], edx -=C2=A0 =C2=A0 mov=C2=A0 =C2=A0esp, eax=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 = = =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0; From now, esp is pointed to per= menent memory +=C2=A0 =C2=A0 mov=C2=A0 =C2=A0esp, eax=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 = = =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0; From now, esp is pointed to per= manent memory ; -=C2=A0 =C2=A0 ; Fixup the ebp point to permenent memory +=C2=A0 =C2=A0 ; Fixup the ebp point to permanent memory ; mov=C2=A0 =C2=A0eax, ebp sub=C2=A0 =C2=A0eax, ebx add=C2=A0 =C2=A0eax, ecx -=C2=A0 =C2=A0 mov=C2=A0 =C2=A0ebp, eax=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 = = =C2=A0 =C2=A0 =C2=A0 ; From now, ebp is pointed to permenent memory +=C2=A0 =C2=A0 mov=C2=A0 =C2=A0ebp, eax=C2=A0 =C2=A0 =C2=A0 =C2=A0 =C2=A0 = = =C2=A0 =C2=A0 =C2=A0 ; From now, ebp is pointed to permanent memory ; ; Fixup callee's ebp point for PeiDispatch @@ -76,7 +76,7 @@ SecSwitchStack=C2=A0 =C2=A0PROC mov=C2=A0 =C2=A0eax, dword ptr [ebp] sub=C2=A0 =C2=A0eax, ebx add=C2=A0 =C2=A0eax, ecx -=C2=A0 =C2=A0 mov=C2=A0 =C2=A0dword ptr [ebp], eax=C2=A0 =C2=A0 ; From no= w, Temporary's PPI caller's stack is in permenent memory +=C2=A0 =C2=A0 mov=C2=A0 =C2=A0dword ptr [ebp], eax=C2=A0 =C2=A0 ; From no= w, Temporary's PPI caller's stack is in permanent memory pop=C2=A0 =C2=A0edx pop=C2=A0 =C2=A0ecx diff --git a/EmulatorPkg/Sec/Sec.c b/EmulatorPkg/Sec/Sec.c index 701032233b..7ee8786c79 100644 --- a/EmulatorPkg/Sec/Sec.c +++ b/EmulatorPkg/Sec/Sec.c @@ -1,5 +1,5 @@ /*++ @file -=C2=A0 Stub SEC that is called from the OS appliation that is the root of= the emulator. +=C2=A0 Stub SEC that is called from the OS application that is the root o= f the emulator. The OS application will call the SEC with the PEI Entry Point API. @@ -89,7 +89,7 @@ _ModuleEntryPoint ( SecReseveredMemorySize +=3D sizeof (EFI_PEI_PPI_DESCRIPTOR); if ((Ppi->Flags & EFI_PEI_PPI_DESCRIPTOR_TERMINATE_LIST) =3D=3D EFI_PEI_PP= I_DESCRIPTOR_TERMINATE_LIST) { -=C2=A0 =C2=A0 =C2=A0 // Since we are appending, need to clear out priviou= s list terminator. +=C2=A0 =C2=A0 =C2=A0 // Since we are appending, need to clear out previou= s list terminator. Ppi->Flags &=3D ~EFI_PEI_PPI_DESCRIPTOR_TERMINATE_LIST; break; } @@ -140,4 +140,3 @@ _ModuleEntryPoint ( } - diff --git a/EmulatorPkg/Sec/Sec.h b/EmulatorPkg/Sec/Sec.h index dd301f7888..42554e05b5 100644 --- a/EmulatorPkg/Sec/Sec.h +++ b/EmulatorPkg/Sec/Sec.h @@ -1,5 +1,5 @@ /*++ @file -=C2=A0 Stub SEC that is called from the OS appliation that is the root of= the emulator. +=C2=A0 Stub SEC that is called from the OS application that is the root o= f the emulator. The OS application will call the SEC with the PEI Entry Point API. @@ -23,7 +23,7 @@ SPDX-License-Identifier: BSD-2-Clause-Patent // -// I think this shold be defined in a MdePkg include file? +// I think this should be defined in a MdePkg include file? // VOID EFIAPI diff --git a/EmulatorPkg/Sec/X64/SwitchRam.S b/EmulatorPkg/Sec/X64/SwitchR= am.S index 7ddb6c854b..59d4e2edef 100644 --- a/EmulatorPkg/Sec/X64/SwitchRam.S +++ b/EmulatorPkg/Sec/X64/SwitchRam.S @@ -1,7 +1,7 @@ #-------------------------------------------------------------------------= ----- # # Copyright (c) 2006 - 2011, Intel Corporation. All rights reserved.
-# Portitions copyright (c) 2011, Apple Inc. All rights reserved. +# Portions copyright (c) 2011, Apple Inc. All rights reserved. # SPDX-License-Identifier: BSD-2-Clause-Patent # #-------------------------------------------------------------------------= ----- diff --git a/EmulatorPkg/Sec/X64/SwitchRam.asm b/EmulatorPkg/Sec/X64/Switc= hRam.asm index 73530bff39..e66bda5bf4 100644 --- a/EmulatorPkg/Sec/X64/SwitchRam.asm +++ b/EmulatorPkg/Sec/X64/SwitchRam.asm @@ -1,7 +1,7 @@ ;-------------------------------------------------------------------------= ----- ; ; Copyright (c) 2006 - 2012, Intel Corporation. All rights reserved.
-; Portitions copyright (c) 2011, Apple Inc. All rights reserved. +; Portions copyright (c) 2011, Apple Inc. All rights reserved. ; SPDX-License-Identifier: BSD-2-Clause-Patent ; ;-------------------------------------------------------------------------= ----- -- 2.20.1 (Apple Git-117) --fnc493s6E4jEsL7WNY3Z Content-Type: text/html; charset="utf-8" Content-Transfer-Encoding: quoted-printable
Fix various typos in EmulatorPkg.
 
Contributed-under: TianoCore Contribution Agreement 1.1
Signed-off-by: Coeur <coeur@gmx.fr>
---
 EmulatorPkg/Sec/Ia32/SwitchRam.S   | 18 +++++++++----= -----
 EmulatorPkg/Sec/Ia32/SwitchRam.asm | 20 ++++++++++----------
 EmulatorPkg/Sec/Sec.c            =   |  5 ++---
 EmulatorPkg/Sec/Sec.h            =   |  4 ++--
 EmulatorPkg/Sec/X64/SwitchRam.S    |  2 +-
 EmulatorPkg/Sec/X64/SwitchRam.asm  |  2 +-
 6 files changed, 25 insertions(+), 26 deletions(-)
 
diff --git a/EmulatorPkg/Sec/Ia32/SwitchRam.S b/EmulatorPkg/Sec/Ia32/= SwitchRam.S
index f24529cc8e..d8298223a9 100644
--- a/EmulatorPkg/Sec/Ia32/SwitchRam.S
+++ b/EmulatorPkg/Sec/Ia32/SwitchRam.S
@@ -9,7 +9,7 @@
 #
 # Abstract:
 #
-#   Switch the stack from temporary memory to permenent me= mory.
+#   Switch the stack from temporary memory to permanent me= mory.
 #
 #--------------------------------------------------------------= ----------------
 
@@ -36,7 +36,7 @@ ASM_PFX(SecSwitchStack):
 
 #
 # !!CAUTION!! this function address's is pushed into stack afte= r
-# migration of whole temporary memory, so need save it to permenent<= /div>
+# migration of whole temporary memory, so need save it to permanent<= /div>
 # memory at first!
 #
 
@@ -44,14 +44,14 @@ ASM_PFX(SecSwitchStack):
     movl  24(%esp), %ecx      &nb= sp;     # Save the second parameter
 
 #
-# Save this function's return address into permenent memory at first= .
-# Then, Fixup the esp point to permenent memory
+# Save this function's return address into permanent memory at first= .
+# Then, Fixup the esp point to permanent memory
 #
 
     movl  %esp, %eax
     subl  %ebx, %eax
     addl  %ecx, %eax
-    movl  (%esp), %edx        &nb= sp;        # copy pushed register's value to permenent = memory
+    movl  (%esp), %edx        &nb= sp;        # copy pushed register's value to permanent = memory
     movl  %edx, (%eax)
     movl  4(%esp), %edx
     movl  %edx, 4(%eax)
@@ -61,16 +61,16 @@ ASM_PFX(SecSwitchStack):
     movl  %edx, 12(%eax)
     movl  16(%esp), %edx
     movl  %edx, 16(%eax)
-    movl  %eax, %esp         = ;          # From now, esp is pointed to permenent= memory
+    movl  %eax, %esp         = ;          # From now, esp is pointed to permanent= memory
 
 #
-# Fixup the ebp point to permenent memory
+# Fixup the ebp point to permanent memory
 #
 #ifndef __APPLE__
     movl   %ebp, %eax
     subl   %ebx, %eax
     addl   %ecx, %eax
-    movl   %eax, %ebp       =           # From now, ebp is pointed to permenent= memory
+    movl   %eax, %ebp       =           # From now, ebp is pointed to permanent= memory
 
 #
 # Fixup callee's ebp point for PeiDispatch
@@ -78,7 +78,7 @@ ASM_PFX(SecSwitchStack):
     movl   (%ebp), %eax
     subl   %ebx, %eax
     addl   %ecx, %eax
-    movl   %eax, (%ebp)      &nbs= p;         # From now, Temporary's PPI caller's stack i= s in permenent memory
+    movl   %eax, (%ebp)      &nbs= p;         # From now, Temporary's PPI caller's stack i= s in permanent memory
 #endif
 
     pop   %edx
diff --git a/EmulatorPkg/Sec/Sec.c b/EmulatorPkg/Sec/Sec.c
index 701032233b..7ee8786c79 100644
--- a/EmulatorPkg/Sec/Sec.c
+++ b/EmulatorPkg/Sec/Sec.c
@@ -1,5 +1,5 @@
 /*++ @file
-  Stub SEC that is called from the OS appliation that is the ro= ot of the emulator.
+  Stub SEC that is called from the OS application that is the r= oot of the emulator.
 
   The OS application will call the SEC with the PEI Entry = Point API.
 
@@ -89,7 +89,7 @@ _ModuleEntryPoint (
     SecReseveredMemorySize +=3D sizeof (EFI_PEI_PPI_D= ESCRIPTOR);
 
     if ((Ppi->Flags & EFI_PEI_PPI_DESCRIPTOR_T= ERMINATE_LIST) =3D=3D EFI_PEI_PPI_DESCRIPTOR_TERMINATE_LIST) {
-      // Since we are appending, need to clear out pr= ivious list terminator.
+      // Since we are appending, need to clear out pr= evious list terminator.
       Ppi->Flags &=3D ~EFI_PEI_PPI_DESCRI= PTOR_TERMINATE_LIST;
       break;
     }
@@ -140,4 +140,3 @@ _ModuleEntryPoint (
 }
 
 
-
diff --git a/EmulatorPkg/Sec/Sec.h b/EmulatorPkg/Sec/Sec.h
index dd301f7888..42554e05b5 100644
--- a/EmulatorPkg/Sec/Sec.h
+++ b/EmulatorPkg/Sec/Sec.h
@@ -1,5 +1,5 @@
 /*++ @file
-  Stub SEC that is called from the OS appliation that is the ro= ot of the emulator.
+  Stub SEC that is called from the OS application that is the r= oot of the emulator.
 
   The OS application will call the SEC with the PEI Entry = Point API.
 
@@ -23,7 +23,7 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 
 
 //
-// I think this shold be defined in a MdePkg include file?
+// I think this should be defined in a MdePkg include file?
 //
 VOID
 EFIAPI
diff --git a/EmulatorPkg/Sec/X64/SwitchRam.S b/EmulatorPkg/Sec/X64/Sw= itchRam.S
index 7ddb6c854b..59d4e2edef 100644
--- a/EmulatorPkg/Sec/X64/SwitchRam.S
+++ b/EmulatorPkg/Sec/X64/SwitchRam.S
@@ -1,7 +1,7 @@
 #--------------------------------------------------------------= ----------------
 #
 # Copyright (c) 2006 - 2011, Intel Corporation. All rights rese= rved.<BR>
-# Portitions copyright (c) 2011, Apple Inc. All rights reserved.
+# Portions copyright (c) 2011, Apple Inc. All rights reserved.
 # SPDX-License-Identifier: BSD-2-Clause-Patent
 #
 #--------------------------------------------------------------= ----------------
diff --git a/EmulatorPkg/Sec/X64/SwitchRam.asm b/EmulatorPkg/Sec/X64/= SwitchRam.asm
index 73530bff39..e66bda5bf4 100644
--- a/EmulatorPkg/Sec/X64/SwitchRam.asm
+++ b/EmulatorPkg/Sec/X64/SwitchRam.asm
@@ -1,7 +1,7 @@
 ;--------------------------------------------------------------= ----------------
 ;
 ; Copyright (c) 2006 - 2012, Intel Corporation. All rights rese= rved.<BR>
-; Portitions copyright (c) 2011, Apple Inc. All rights reserved.
+; Portions copyright (c) 2011, Apple Inc. All rights reserved.
 ; SPDX-License-Identifier: BSD-2-Clause-Patent
 ;
 ;--------------------------------------------------------------= ----------------
-- 
2.20.1 (Apple Git-117)
 
--fnc493s6E4jEsL7WNY3Z--
diff --git a/EmulatorPkg/Sec/Ia32/SwitchRam.asm b/EmulatorPkg/Sec/Ia3= 2/SwitchRam.asm
index 9c7908f7a0..99ef002980 100644
--- a/EmulatorPkg/Sec/Ia32/SwitchRam.asm
+++ b/EmulatorPkg/Sec/Ia32/SwitchRam.asm
@@ -9,7 +9,7 @@
 ;
 ; Abstract:
 ;
;   Switch the stack from temporary memory to permenent me= mory.
 ;
 ;--------------------------------------------------------------= ----------------
 
@@ -36,7 +36,7 @@ SecSwitchStack   PROC
 
     ;
     ; !!CAUTION!! this function address's is pushed i= nto stack after
; migration of whole temporary memory, so need save it= to permenent
     ; memory at first!
     ;
 
@@ -44,13 +44,13 @@ SecSwitchStack   PROC
     mov   ecx, [esp + 24]    &nbs= p;     ; Save the second parameter
 
     ;
; Save this function's return address into permenent m= emory at first.
; Then, Fixup the esp point to permenent memory
     ;
     mov   eax, esp
     sub   eax, ebx
     add   eax, ecx
-    mov   edx, dword ptr [esp]    &nbs= p;    ; copy pushed register's value to permenent memory
+    mov   edx, dword ptr [esp]    &nbs= p;    ; copy pushed register's value to permanent memory
     mov   dword ptr [eax], edx
     mov   edx, dword ptr [esp + 4]
     mov   dword ptr [eax + 4], edx
@@ -58,17 +58,17 @@ SecSwitchStack   PROC
     mov   dword ptr [eax + 8], edx
     mov   edx, dword ptr [esp + 12]
     mov   dword ptr [eax + 12], edx
-    mov   edx, dword ptr [esp + 16]   = ; Update this function's return address into permenent memory
+    mov   edx, dword ptr [esp + 16]   = ; Update this function's return address into permanent memory
     mov   dword ptr [eax + 16], edx
-    mov   esp, eax        &n= bsp;            ; From now, esp is pointed to= permenent memory
+    mov   esp, eax        &n= bsp;            ; From now, esp is pointed to= permanent memory
 
     ;
; Fixup the ebp point to permenent memory
     ;
     mov   eax, ebp
     sub   eax, ebx
     add   eax, ecx
-    mov   ebp, eax        &n= bsp;       ; From now, ebp is pointed to permenent memory
+    mov   ebp, eax        &n= bsp;       ; From now, ebp is pointed to permanent memory
 
     ;
     ; Fixup callee's ebp point for PeiDispatch
@@ -76,7 +76,7 @@ SecSwitchStack   PROC
     mov   eax, dword ptr [ebp]
     sub   eax, ebx
     add   eax, ecx
-    mov   dword ptr [ebp], eax    ; Fr= om now, Temporary's PPI caller's stack is in permenent memory
+    mov   dword ptr [ebp], eax    ; Fr= om now, Temporary's PPI caller's stack is in permanent memory
 
     pop   edx
     pop   ecx
@@ -9,7 +9,7 @@
 ; Abstract:
 ;
-;   Switch the stack from temporary memory to permenent me= mory.
+;   Switch the stack from temporary memory to permanent me= mory.
 ;
 ;--------------------------------------------------------------= ----------------
@@ -36,7 +36,7 @@ SecSwitchStack   PROC
     ;
     ; !!CAUTION!! this function address's is pushed i= nto stack after
-    ; migration of whole temporary memory, so need save it= to permenent
+    ; migration of whole temporary memory, so need save it= to permanent
     ; memory at first!
     ;
@@ -44,13 +44,13 @@ SecSwitchStack   PROC
 
     ;
-    ; Save this function's return address into permenent m= emory at first.
-    ; Then, Fixup the esp point to permenent memory
+    ; Save this function's return address into permanent m= emory at first.
+    ; Then, Fixup the esp point to permanent memory
     ;
     mov   eax, esp
@@ -58,17 +58,17 @@ SecSwitchStack   PROC
 
     ;
-    ; Fixup the ebp point to permenent memory
+    ; Fixup the ebp point to permanent memory
     ;
     mov   eax, ebp